searchData={"items":[{"type":"module","title":"ShopSearch","doc":"Elixir library to easily fetch and transform product data from Shopify stores.\n\nThis module provides functionality to:\n- Fetch all products from a Shopify store\n- Fetch products with pagination\n- Find a specific product by its handle\n- Fetch collections and their products\n- Transform Shopify product data into a consistent format","ref":"ShopSearch.html"},{"type":"function","title":"ShopSearch.get_all_collections/1","doc":"Fetches all collections from the Shopify store.","ref":"ShopSearch.html#get_all_collections/1"},{"type":"function","title":"Examples - ShopSearch.get_all_collections/1","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    iex> {:ok, collections} = ShopSearch.get_all_collections(store)","ref":"ShopSearch.html#get_all_collections/1-examples"},{"type":"function","title":"ShopSearch.get_all_products/1","doc":"Fetches all products from the Shopify store.","ref":"ShopSearch.html#get_all_products/1"},{"type":"function","title":"Examples - ShopSearch.get_all_products/1","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    iex> {:ok, products} = ShopSearch.get_all_products(store)","ref":"ShopSearch.html#get_all_products/1-examples"},{"type":"function","title":"ShopSearch.get_collection/2","doc":"Finds a specific collection by its handle.","ref":"ShopSearch.html#get_collection/2"},{"type":"function","title":"Parameters - ShopSearch.get_collection/2","doc":"- `store`: ShopSearch client\n- `handle`: Collection handle string","ref":"ShopSearch.html#get_collection/2-parameters"},{"type":"function","title":"Examples - ShopSearch.get_collection/2","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    iex> {:ok, collection} = ShopSearch.get_collection(store, \"featured-collection\")","ref":"ShopSearch.html#get_collection/2-examples"},{"type":"function","title":"ShopSearch.get_collection_products/2","doc":"Fetches all products from a specific collection.","ref":"ShopSearch.html#get_collection_products/2"},{"type":"function","title":"Parameters - ShopSearch.get_collection_products/2","doc":"- `store`: ShopSearch client\n- `collection_handle`: Collection handle string","ref":"ShopSearch.html#get_collection_products/2-parameters"},{"type":"function","title":"Examples - ShopSearch.get_collection_products/2","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    iex> {:ok, products} = ShopSearch.get_collection_products(store, \"featured\")","ref":"ShopSearch.html#get_collection_products/2-examples"},{"type":"function","title":"ShopSearch.get_collection_products_paginated/3","doc":"Fetches products from a specific collection with pagination.","ref":"ShopSearch.html#get_collection_products_paginated/3"},{"type":"function","title":"Parameters - ShopSearch.get_collection_products_paginated/3","doc":"- `store`: ShopSearch client\n- `collection_handle`: Collection handle string\n- `opts`: Options map with optional `:limit` and `:page` keys","ref":"ShopSearch.html#get_collection_products_paginated/3-parameters"},{"type":"function","title":"Examples - ShopSearch.get_collection_products_paginated/3","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    iex> {:ok, products} = ShopSearch.get_collection_products_paginated(store, \"featured\", %{limit: 10})","ref":"ShopSearch.html#get_collection_products_paginated/3-examples"},{"type":"function","title":"ShopSearch.get_product/2","doc":"Finds a specific product by its handle.","ref":"ShopSearch.html#get_product/2"},{"type":"function","title":"Parameters - ShopSearch.get_product/2","doc":"- `store`: ShopSearch client\n- `handle`: Product handle string","ref":"ShopSearch.html#get_product/2-parameters"},{"type":"function","title":"Examples - ShopSearch.get_product/2","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    iex> {:ok, product} = ShopSearch.get_product(store, \"awesome-product\")","ref":"ShopSearch.html#get_product/2-examples"},{"type":"function","title":"ShopSearch.get_products/2","doc":"Fetches products with pagination options.","ref":"ShopSearch.html#get_products/2"},{"type":"function","title":"Parameters - ShopSearch.get_products/2","doc":"- `store`: ShopSearch client\n- `opts`: Options map with optional `:limit` and `:page` keys","ref":"ShopSearch.html#get_products/2-parameters"},{"type":"function","title":"Examples - ShopSearch.get_products/2","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    iex> {:ok, products} = ShopSearch.get_products(store, %{limit: 25, page: 1})","ref":"ShopSearch.html#get_products/2-examples"},{"type":"function","title":"ShopSearch.new/1","doc":"Creates a new ShopSearch client for a Shopify store.","ref":"ShopSearch.html#new/1"},{"type":"function","title":"Parameters - ShopSearch.new/1","doc":"- `domain`: The Shopify store domain (e.g., \"your-store.myshopify.com\")","ref":"ShopSearch.html#new/1-parameters"},{"type":"function","title":"Examples - ShopSearch.new/1","doc":"iex> store = ShopSearch.new(\"example-store.myshopify.com\")\n    %ShopSearch{domain: \"example-store.myshopify.com\"}","ref":"ShopSearch.html#new/1-examples"},{"type":"type","title":"ShopSearch.t/0","doc":"","ref":"ShopSearch.html#t:t/0"},{"type":"extras","title":"ShopSearch","doc":"# ShopSearch\n\nElixir library to easily fetch and transform product data from Shopify stores.","ref":"readme.html"},{"type":"extras","title":"Features - ShopSearch","doc":"- Fetch all products from a Shopify store\n- Fetch products with pagination\n- Find a specific product by its handle\n- Fetch collections and their products\n- Transform Shopify product data into a consistent format","ref":"readme.html#features"},{"type":"extras","title":"Installation - ShopSearch","doc":"Add `shop_search` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:shop_search, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ShopSearch","doc":"# Create a store client\n```elixir\nstore = ShopSearch.new(\"your-store.myshopify.com\")\n```\n\n# Fetch all products\n```elixir\n{:ok, products} = ShopSearch.get_all_products(store)\n```\n\n# Fetch products with pagination\n```elixir\n{:ok, products} = ShopSearch.get_products(store, %{limit: 25, page: 1})\n```\n\n# Find a specific product\n```elixir\n{:ok, product} = ShopSearch.get_product(store, \"awesome-product\")\n```\n\n# Fetch all collections\n```elixir\n{:ok, collections} = ShopSearch.get_all_collections(store)\n```\n\n# Get products from a collection\n```elixir\n{:ok, products} = ShopSearch.get_collection_products(store, \"featured\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.1.0] - 2025-06-28","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release\n- Support for fetching all products from Shopify stores\n- Product pagination support\n- Find specific products by handle\n- Collection fetching and product listing\n- Data transformation to consistent format\n- Comprehensive documentation and examples","ref":"changelog.html#added"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}